﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows.Input;
using Microsoft.Practices.Composite.Presentation.Commands;
using System.ComponentModel;
using System.Collections.ObjectModel;

namespace WpfApplication6
{
    public class ScoreListViewModel : INotifyPropertyChanged
    {
        public ScoreListViewModel()
        {            
            this.StudentList = new ObservableCollection<Student>(StudentService.RetrieveStudentList());

            AddCommand = new DelegateCommand<object>(OnAdd, arg => true);
            ModifyCommand = new DelegateCommand<object>(OnModify, arg => true);
            RemoveCommand = new DelegateCommand<object>(OnRemove, arg => true);

            this.PropertyChanged += ModelPropertyChanged;
        }

        void ModelPropertyChanged(object sender, PropertyChangedEventArgs e)
        {
            switch (e.PropertyName)
            {
                case "IsPassed":
                    this.StudentList = new ObservableCollection<Student>(
                        this.IsPassed ? StudentService.RetrievePassedStudentList() : StudentService.RetrieveStudentList());

                    break;
                default:
                    break;
            }
        }

        public ScoreListView View { get; set; }

        private bool isPassed;
        public bool IsPassed
        {
            get
            {
                return this.isPassed;
            }
            set
            {
                if (this.isPassed != value)
                {
                    this.isPassed = value;
                    OnPropertyChanged("IsPassed");
                }
            }
        }

        public ObservableCollection<Student> StudentList { get; set; }

        public ICommand AddCommand { get; set; }
        public ICommand ModifyCommand { get; set; }
        public ICommand RemoveCommand { get; set; }

        public void OnAdd(object obj)
        {
            this.StudentList.Add(new Student() { UserId = 7, UserName = "李永京", Score = 75 });
        }

        public void OnModify(object obj)
        {
            var item = this.StudentList.SingleOrDefault(x => x.UserId == 1);
            if (item != null)
            {
                item.Score = 0;
                //item = new Student() { UserId = item.UserId, UserName = item.UserName, Score = 0 };
            }
        }

        public void OnRemove(object obj)
        {
            var item = this.StudentList.SingleOrDefault(x => x.UserId == 2);
            if (item != null)
            {
                this.StudentList.Remove(item);
            }
        }

        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            PropertyChangedEventHandler handler = this.PropertyChanged;
            if (handler != null)
            {
                handler(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion
    }
}